// noinspection JSVoidFunctionReturnValueUsed

import { PointLayer, RasterLayer, HeatmapLayer, PolygonLayer } from '@antv/l7'

// 车牌号图层
export function addLicenseLayer(scene, msg) {
  const pointLayer = new PointLayer()
    .source(msg, {
      parser: {
        type: 'json',
        x: 'longitude',
        y: 'latitude',
      },
    })
    .shape('picLicense', 'text')
    // .shape('originalType', 'text')
    .size(9)
    .style({
      textAllowOverlap: true,
      raisingHeight: 10,
      stroke: '#01309b',
      strokeWidth: 2,
      halo: 1,
    })
    .color('#ffffff')
    .on('contextmenu', (e) => {
      const input = document.createElement('input')
      input.setAttribute('readonly', 'readonly')
      input.setAttribute('value', e.feature.id)
      document.body.appendChild(input)
      input.setSelectionRange(0, 9999)
      input.select()
      document.execCommand('copy')
      document.body.removeChild(input)
      ELEMENT.Message('复制ID成功！')
    })
  scene.addLayer(pointLayer)
  return pointLayer
}

// 车辆圆点图层
export function addVehicleLayer(scene, msg) {
  const pointLayer = new PointLayer()
    .source(msg, {
      parser: {
        type: 'json',
        x: 'longitude',
        y: 'latitude',
      },
    })
    .shape('circle')
    .style({
      blur: 1,
    })
    .size(6)
    .color('#06f4fe')
  scene.addLayer(pointLayer)
  return pointLayer
}

// 等待行人数量文本图层
export function addPasserbyText(scene, msg) {
  const pointLayer = new PointLayer()
    .source(msg, {
      parser: {
        type: 'json',
        x: 'x',
        y: 'y',
      },
    })
    .shape('text', 'text')
    .size(10)
    .style({
      raisingHeight: 32,
      textAllowOverlap: true,
      stroke: 'red',
      strokeWidth: 1,
    })
    .color('white')
  scene.addLayer(pointLayer)
  return pointLayer
}

// 路口图层
export function addCrossPoint(scene, msg, offset, callback) {
  let pointLayer = new PointLayer({ zIndex: 2 })
    .source(msg, {
      parser: {
        type: 'json',
        x: 'longitude',
        y: 'latitude',
      },
    })
    .style({
      offsets: offset,
    })
    .shape('cross_location')
    .size(14)
    .active({
      color: '#ffffff',
      mix: 0.6,
    })
    .on('click', (e) => {
      callback(e)
    })
  scene.addLayer(pointLayer)
  return pointLayer
}

// 路口名称图层
export function addCrossDetailPoint(scene, msg) {
  const pointLayer = new PointLayer({ zIndex: 3 })
    .source(msg, {
      parser: {
        type: 'json',
        x: 'longitude',
        y: 'latitude',
      },
    })
    .style({
      textAllowOverlap: true,
      raisingHeight: 0,
      stroke: '#01309b',
      strokeWidth: 2,
      halo: 1,
    })
    .color('#ffffff')
    .shape('name', 'text')
    .size(12)
  // .active(true)
  scene.addLayer(pointLayer)
  return pointLayer
}

// 天交通事件点图 && 热力图
export function addTrafficEventPoint1(scene, msg, callback) {
  const pointLayer = new PointLayer()
    .source(msg, {
      parser: {
        type: 'json',
        x: 'lng',
        y: 'lat',
      },
    })
    .style({
      offsets: [0, 0],raisingHeight: 10,

    })
    .shape('event')
    .size(12)
    .on('click', (e) => {
      callback(e)
    })
  scene.addLayer(pointLayer)
  return pointLayer
}
export function addTrafficEventPoint1Heat(scene, msg) {
  const layer = new HeatmapLayer({})
    .source(msg, {
      parser: {
        type: 'json',
        x: 'lng',
        y: 'lat',
      },
    })
    .shape('heatmap')
    .style({
      intensity: 2,
      radius: 20,
      rampColors: {
        colors: [
          'rgba(253, 108, 3,1)',
          'rgba(252, 145, 3,0.9)',
          'rgba(190, 236, 68,0.9)',
          'rgba(83, 231, 169,0.8)',
          'rgba(36, 239, 219,0.7)',
          'rgba(38, 233, 251,0.2)',
        ].reverse(),
        positions: [0, 0.2, 0.4, 0.6, 0.8, 1.0],
      },
    })
  scene.addLayer(layer)
  return layer
}

// 周交通事件热力图
export function addTrafficEventPoint2(scene, msg) {
  const layer = new HeatmapLayer({})
    .source(msg, {
      parser: {
        type: 'json',
        x: 'lng',
        y: 'lat',
      },
    })
    .shape('heatmap')
    .style({
      intensity: 2,
      radius: 20,
      rampColors: {
        colors: [
          'rgba(253, 108, 3,1)',
          'rgba(252, 145, 3,0.9)',
          'rgba(190, 236, 68,0.9)',
          'rgba(83, 231, 169,0.8)',
          'rgba(36, 239, 219,0.7)',
          'rgba(38, 233, 251,0.2)',
        ].reverse(),
        positions: [0, 0.2, 0.4, 0.6, 0.8, 1.0],
      },
    })
  scene.addLayer(layer)
  return layer
}

// 月交通事件热力图
export function addTrafficEventPoint3(scene, msg) {
  const layer = new HeatmapLayer({})
    .source(msg, {
      parser: {
        type: 'json',
        x: 'lng',
        y: 'lat',
      },
    })
    .shape('heatmap')
    .style({
      intensity: 2,
      radius: 20,
      rampColors: {
        colors: [
          'rgba(253, 108, 3,1)',
          'rgba(252, 145, 3,0.9)',
          'rgba(190, 236, 68,0.9)',
          'rgba(83, 231, 169,0.8)',
          'rgba(36, 239, 219,0.7)',
          'rgba(38, 233, 251,0.2)',
        ].reverse(),
        positions: [0, 0.2, 0.4, 0.6, 0.8, 1.0],
      },
    })
  scene.addLayer(layer)
  return layer
}

// 设备图层 ---
export function addEquipmentMilli(scene, msg, callback) {
  msg.map(item =>{
    item.x = item.wkt.split(',')[0]
    item.y = item.wkt.split(',')[1]
  })
  const pointLayer = new PointLayer()
    .source(msg, {
      parser: {
        type: 'json',
        x: 'x',
        y: 'y',
      },
    })
    .style({
      offsets: [0, 20],
    })
    .shape('milli')
    .size(20)
    .on('click', (e) => {
      callback(e)
    })
  scene.addLayer(pointLayer)
  return pointLayer
}
export function addEquipmentLaser(scene, msg, callback) {
  msg.map(item =>{
    item.x = item.wkt.split(',')[0]
    item.y = item.wkt.split(',')[1]
  })
  const pointLayer = new PointLayer()
    .source(msg, {
      parser: {
        type: 'json',
        x: 'x',
        y: 'y',
      },
    })
    .style({
      offsets: [0, 20],
    })
    .shape('laser')
    .size(20)
    .on('click', (e) => {
      callback(e)
    })
  scene.addLayer(pointLayer)
  return pointLayer
}
export function addEquipmentWeather(scene, msg, callback) {
  msg.map(item =>{
    item.x = item.wkt.split(',')[0]
    item.y = item.wkt.split(',')[1]
  })
  const pointLayer = new PointLayer()
    .source(msg, {
      parser: {
        type: 'json',
        x: 'x',
        y: 'y',
      },
    })
    .style({
      offsets: [0, 20],
    })
    .shape('weather')
    .size(20)
    .on('click', (e) => {
      callback(e)
    })
  scene.addLayer(pointLayer)
  return pointLayer
}
export function addEquipmentCamera(scene, msg, callback) {
  msg.map(item =>{
    item.x = item.wkt.split(',')[0]
    item.y = item.wkt.split(',')[1]
  })
  const pointLayer = new PointLayer()
    .source(msg, {
      parser: {
        type: 'json',
        x: 'x',
        y: 'y',
      },
    })
    .style({
      offsets: [0, 20],
    })
    .shape('camera')
    .size(20)
    .on('click', (e) => {
      callback(e)
    })
  scene.addLayer(pointLayer)
  return pointLayer
}
export function addEquipmentSign(scene, msg, callback) {
  msg.map(item =>{
    item.x = item.wkt.split(',')[0]
    item.y = item.wkt.split(',')[1]
  })
  const pointLayer = new PointLayer()
    .source(msg, {
      parser: {
        type: 'json',
        x: 'x',
        y: 'y',
      },
    })
    .style({
      offsets: [0, 20],
    })
    .shape('sign')
    .size(20)
    .on('click', (e) => {
      callback(e)
    })
  scene.addLayer(pointLayer)
  return pointLayer
}
// ------------

export function addSignalCross(scene, msg, callback) {
  const pointLayer = new PointLayer({ zIndex: 2 })
    .source(msg, {
      parser: {
        type: 'json',
        x: 'lng',
        y: 'lat',
      },
    })
    .style({
      offsets: [0, 0],
    })
    .shape('cross_location')
    .size(14)
    .active(true)
    .on('click', callback)
  scene.addLayer(pointLayer)
  return pointLayer
}

export function addSignalRoad(scene, msg, callback) {
  console.log('msg', msg)
  const lineLayer = new PolygonLayer({ zIndex: 1 })
    .source(msg)
    .style({
      opacity: 0.4,
    })
    .active(true)
    .shape('fill')
    .size(2)
    .color('#F39800')
    .on('click', callback)
  scene.addLayer(lineLayer)
  return lineLayer
}
